==> gpm_api-0.2.12.tar.gz: gpm_api-0.2.12/gpm/retrievals/retrieval_2a_pmw.py <==
# -----------------------------------------------------------------------------.
# MIT License

# Copyright (c) 2024 GPM-API developers
#
# This file is part of GPM-API.

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

# -----------------------------------------------------------------------------.
"""This module contains GPM PMW 2A products community-based retrivals."""


def retrieve_totalWaterPath(ds):
    """Retrieve clutter height."""
    da = ds["rainWaterPath"] + ds["cloudWaterPath"] + ds["iceWaterPath"]
    da.name = "totalWaterPath"
    return da


def retrieve_liquidPrecipitation(ds):
    """Retrieve clutter height."""
    da = ds["surfacePrecipitation"] - ds["frozenPrecipitation"]
    da.name = "liquidPrecipitation"
    da.attrs = ds["surfacePrecipitation"].attrs.copy()
    da.attrs["description"] = "surfacePrecipitation - frozenPrecipitation"
    return da

==> gpm_api-0.3.3.tar.gz: gpm_api-0.3.3/gpm/retrievals/retrieval_2a_pmw.py <==
# -----------------------------------------------------------------------------.
# MIT License

# Copyright (c) 2024 GPM-API developers
#
# This file is part of GPM-API.

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

# -----------------------------------------------------------------------------.
"""This module contains GPM PMW 2A products community-based retrievals."""


def retrieve_totalWaterPath(ds):
    """Retrieve clutter height."""
    da = ds["rainWaterPath"] + ds["cloudWaterPath"] + ds["iceWaterPath"]
    da.name = "totalWaterPath"
    return da


def retrieve_liquidPrecipitation(ds):
    """Retrieve clutter height."""
    da = ds["surfacePrecipitation"] - ds["frozenPrecipitation"]
    da.name = "liquidPrecipitation"
    da.attrs = ds["surfacePrecipitation"].attrs.copy()
    da.attrs["description"] = "surfacePrecipitation - frozenPrecipitation"
    return da
